#! /usr/bin/env python3

#  Program name:  TRYDAP.py. 

#  This Python console program is used for  initial  TRYSYS  runs.  
#  It prompts for the name of Command & Data files and then runs TRYSYS.
#  After a run is finished it prompts for a name for the output file.
#  If *GIVE is present in the command file, it prompts for a name for
#  the binary GIVE to be saved

#  Python Programmer: William C. Schulz, PhD  NaU  NovaTrantor V
#  Original version date: 12.29.13
#  Latest mods by William Schulz: 7/12/14; 11/28/15 
#  Latest mods by Robert Dean: 9/2/15; 12/15/17; 1/30/19 


import os, sys, string, math, re, shutil



sys.path.insert(1,'c:/trysys')          #Under Windows one MUST use  / s  in path statements!  ADDED July 2015.
                                        #Gives the path for locating user-developed modules to be imported.
 
import massagemodASCII                  #Use for Unicodes =< 255.  E.g., accented & unaccented Latin characters. 
                                        #These use use 1 byte of storage.
										
import massagemodUTF8                   #Use for Unicode codes => 256. Cyrillic, Chinese, Arabic, Korean and so on.
                                        #These require 2+ bytes of storage at a minimum.
 
import massagemodFR                     #Imports an ASCII version where certain TRYSYS output phrases
                                        #are translated into French.

#import massagemodDE
#import massagemodES


if os.path.isfile("MTXIN1"):            # Deletes files MTXIN1, MONIN, MONOUT, MONPUN, GIVE,
	os.remove("MTXIN1")             # & TAKE  i f  t h e y  e x i s t .

if os.path.isfile("MONIN"):
	os.remove("MONIN")

if os.path.isfile("MONOUT"):
	os.remove("MONOUT")

if os.path.isfile("MONPUN"):
	os.remove("MONPUN")



if os.path.isfile("TAKE"):
	os.remove("TAKE")

if os.path.isfile("GIVE"):
	os.remove("GIVE")
	
print("\n This  T R Y D A P  console app manages TRYSYS runs for processing raw data,")
print("  calculating correlations & initial communality estimates, and so on.")
 # print("\n Note that TRYDAP first deletes any TRYSYS temp. system files found.") 
print("\n (Use  TRYTAKE  for runs that require a saved correlation matrix.) \n\n\n")

print(' Does your cmdfile contain Unicode characters (e.g., Chinese, Cyrillic, etc.)?\n')
#print('  If YES, enter yes or y:')
ascutf = input('  If Yes, enter yes or y; if NO, press  R e t u r n : ')
print(ascutf)

finished = False                                                     #Gets the name of command file
while not finished:                                                  #Tests if this command file exists
	cmdfilestring = input("  Enter the name of your Command file: ")
	finished = os.path.isfile(cmdfilestring)
	if not finished:
		print("\n  That file does not exist in this directory.  Try again. ")        
		print("     (Or close the console window and restart TRYDAP.) \n")	



finished = False                                                     #Gets the name of data file
while not finished:                                                  #Tests if this data file exists
	datafilestring = input("\n  Enter the name of your Data file: ")
	finished = os.path.isfile(datafilestring)
	if not finished:
		print("\n  That file does not exist in this directory.  Try again. ") 
		print("     (Or close the console window and restart TRYDAP.) \n\n")		
   

shutil.copy(cmdfilestring, "MONIN")                                  #Copies the commandfile to MONIN
shutil.copy(datafilestring, "MTXIN1")                                #Copies the datafile to MTXIN1

#####
os.system('C:/TRYSYS/TRYSYS20.exe')    #Gives the default path to the trysys executable.  ADDED July 2015.
#####

print("\n\n   Enter a name for your analysis  O u t p u t  file.") 
outfilestring = input ("   (The extension name  outM  is given to this file.):")

#print("\n\nThe extension name  outM  will be added.")
### So the program always uses  outM  for the extension name.
### Modify old massagemodxx  code that adds an  M  to the user-specified output file name. 

shutil.copy("MONOUT", outfilestring) 

if (ascutf == 'yes' or ascutf == 'y'):
	massagemodUTF8.massage(outfilestring)                               
else:
	print('\n  Select a 2nd language for some of the output: Return for English;')
	lang = input('\n   fr for Français; es for Español; de for Deutsch:')
	if (lang == 'fr'):
		massagemodFR.massage(outfilestring)
	elif(lang == 'de'):
		pass
	elif(lang ==  'es'):
		pass
	else:
		massagemodASCII.massage(outfilestring)

if os.path.isfile("GIVE"):                                                          #Renames the GIVE file
	print("\n  Enter a name for your requested binary output file  G I V E .")   
	givestring = input("  (The extension name  giv  will be added.): ")
	if len(givestring) < 2:
		pass
	else:
		givestring = givestring + ".giv"
		shutil.copy("GIVE", givestring)
		


endit = input("\n  Press Return to exit the program.")
