﻿#! /usr/bin/env python3

# Program name "TRYTAKE.py"

# This app is used for TRYSYS runs requiring a saved GIVE file.  
# It prompts for the name of Command and GIVE files.
# It then copies the input GIVE file to the TRYSYS system
# file TAKE. Any existing TAKE files are deleted before this.
# After TRYSYS has run, the user is prompted for a name for the
# Output file and a name for any requested GIVE output file. 
#
#  Programmer:   William C. Schulz PhD,  NaU  NovaTrantor V

#  Original Version date: 12.31.13

#  Latest mods by Robert Dean:  5/17/16; 12/24/18; 1/30/19

import os, sys, string, math, re, shutil 


sys.path.insert(1,'c:/trysys') #Gives the (standard) path to the trysys executable.  Added July 2015. RBD
 
 
import massagemodASCII         #Use for Unicode characters =< 255.  I.e., accented & unaccented Latin characters.
                           
import massagemodUTF8          #Use for 2+ byte Unicode characters => 256. E.g., Chinese, Cyrillic, and so on.

import massagemodFR            #Intro French version

#import massagemodde           #Intro German version      Yet to be implemented.
#import massagemodes           #Intro Spanish version      "  "  "     "    "      


if os.path.isfile("MTXIN1"):          # Deletes MTXIN1, MONIN, MONOUT, GIVE & TAKE, 
	os.remove("MTXIN1")               #  i f  they pre-exist before a new run.
	
if os.path.isfile("MONIN"):
	os.remove("MONIN")
	
if os.path.isfile("MONOUT"):
	os.remove("MONOUT")
	
if os.path.isfile("MONPUN"):
	os.remove("MONPUN")

if os.path.isfile("TAKE"):
	os.remove("TAKE")

if os.path.isfile("GIVE"):
	os.remove("GIVE")
	
print("\n  This  T R Y T A K E  console app manages TRYSYS runs where correlations,")
print("   communalities, and so on have been saved in a binary GIVE file.")
# print("\n Note that TRYTAKE first deletes any TRYSYS temp. system files found.")
print("\n  The command file for these runs  m u s t  include a  *TAKE  command.")
print("\n  (Use  TRYDAP  to process raw data, calculate correlations, etc.)\n\n\n")

print('  Does your cmdfile contain Unicode characters (e.g., Chinese, Cyrillic etc.)?\n')
#print('   If Yes, enter y or yes:')
ascutf = input('   If YES, enter y or yes; if NO press  R e t u r n : ')
#print(ascutf)

finished = False                                                        #Gets name of command file;
while not finished:                                                     # tests if it exists.
	cmdfilestring = input("\n   Enter the name of your Command file: ")
	finished = os.path.isfile(cmdfilestring)
	if not finished:
		print("\n   That file does not exist in this directory.  Try again.")
		print("     (Or close the console window and restart TRYTAKE.)")	
		
shutil.copy(cmdfilestring, "MONIN")  		         #Copies commandfile to MONIN.
		
finished = False                                     #Gets name of a saved binary  GIVE  file.
while not finished: 

	givefilestring = input("\n   Enter the name of your pre-existing binary  G I V E  file:  ")
	if len(givefilestring) <2:
		shutil.copy("GIVE", "TAKE")
		finished = True
	else:		
		finished = os.path.isfile(givefilestring)
		if not finished:
			print("\n   That file does not exist in this directory.  Try again.")
			print("     (Or close the console window and restart TRYTAKE.)")				
		else:
			shutil.copy(givefilestring, "TAKE")
	
	
# PRINT("\n\n    ")		
                                      

os.system('c:/trysys/trysys20.exe')                                   #Gives the path to the trysys executable.  
		                                                            #Note the full path. Changeable of course.
															  
print("\n\n   Enter a name for your analysis  O u t p u t  file.")  #Prompts for a user-specified output file name	
#print("\n   (The extension name  outM  will be added.):"   
outfilestring = input ("   (The file extension name  outM  will be used.):")
 

shutil.copy("MONOUT", outfilestring)                              #Copies output file MONOUT to user-named file.
  
# massagemodascii.massage(outfilestring)                          #Massages the output file for later editing.
if (ascutf == 'yes' or ascutf == 'y'):
	massagemodUTF8.massage(outfilestring)                               
else:
	print('\n   Select a 2nd language for the output. Or press Return for English.')
	lang = input('\n    Enter fr for Français; [es for Español; de for Deutsch]:')
	if (lang == 'fr'):
		massagemodFR.massage(outfilestring)
	elif(lang == 'de'):
		pass
	elif(lang ==  'es'):
		pass
	else:
		massagemodASCII.massage(outfilestring)	
		
if os.path.isfile("GIVE"):                                                             
	print("\n   Enter a name for your requested GIVE binary output file.")   
	givestring = input("    (The file extension name  giv  will be used.): ")
	if len(givestring) < 2:
		pass
	else:
		givestring = givestring + ".giv"
		shutil.copy("GIVE", givestring)		


endit = input("\n   Press Return to exit the program.")
